from .stparser import get_type, check_type, parse_types

__all__ = ["get_type", "check_type", "parse_types"]

__version__ = '0.1.0'
